@@ -1,41 +1,38 @@
 #
 # IB structs
 #
-CommissionReport <- list(execId=              "",
-                         commission=          0,
-                         currency=            "",
-                         realizedPNL=         0,
-                         yield=               0,
-                         yieldRedemptionDate= 0L)     # yyyymmdd format
 
-Execution <- list(execId=        "",
+Execution <- list(orderId=       0L,
+                  execId=        "",
                   time=          "",
                   acctNumber=    "",
                   exchange=      "",
                   side=          "",
                   shares=        0,
                   price=         0,
-                  permId=        0L,
+                  permId=        "",
                   clientId=      0L,
-                  orderId=       0L,
-                  liquidation=   0L,
+                  liquidation=   FALSE,
                   cumQty=        0,
                   avgPrice=      0,
                   orderRef=      "",
                   evRule=        "",
-                  evMultiplier=  0,
+                  evMultiplier=  NA_real_,
                   modelCode=     "",
                   lastLiquidity= 0L,
                   pendingPriceRevision= FALSE,
-                  submitter=     "")
+                  submitter=     "",
+                  optExerciseOrLapseType= "")
 
-ExecutionFilter <- list(clientId= 0L,
-                        acctCode= "",
-                        time=     "",
-                        symbol=   "",
-                        secType=  "",
-                        exchange= "",
-                        side=     "")
+ExecutionFilter <- list(clientId=      0L,
+                        acctCode=      "",
+                        time=          "",
+                        symbol=        "",
+                        secType=       "",
+                        exchange=      "",
+                        side=          "",
+                        lastNDays=     NA_integer_,
+                        specificDates= integer())
 
 ComboLeg  <- list(conId=              0L,
                   ratio=              0L,
@@ -57,9 +54,9 @@ Contract  <- list(conId=                        0L,
                                                     # - lastTradedDateOrContractMonth / bond maturity
                                                     # - ContractDetails$lastTradeTime
                                                     # - ContractDetails$timeZoneId
-                  strike=                       0,
+                  strike=                       NA_real_,
                   right=                        "",
-                  multiplier=                   "",
+                  multiplier=                   NA_real_,
                   exchange=                     "",
                   primaryExchange=              "",
                   currency=                     "",
@@ -102,6 +99,7 @@ ContractDetails <- list(contract=           Contract,
                         minSize=            NA_real_,
                         sizeIncrement=      NA_real_,
                         suggestedSizeIncrement= NA_real_,
+                        minAlgoSize=        NA_real_,
                         secIdList=          character(),
                         cusip=              "",
                         ratings=            "",
@@ -135,21 +133,21 @@ ContractDetails <- list(contract=           Contract,
                         fundBlueSkyTerritories=          "",
                         fundDistributionPolicyIndicator= "",
                         fundAssetType=                   "",
-                        ineligibilityReasonList=         list())
-
-ContractDescription <- list(contract=           Contract,
-                            derivativeSecTypes= character())
+                        ineligibilityReasonList=         list(),
+                        eventContract1=                  "",
+                        eventContractDescription1=       "",
+                        eventContractDescription2=       "")
 
 OrderState  <- list(status=               "",
-                    initMarginBefore=     "",
-                    maintMarginBefore=    "",
-                    equityWithLoanBefore= "",
-                    initMarginChange=     "",
-                    maintMarginChange=    "",
-                    equityWithLoanChange= "",
-                    initMarginAfter=      "",
-                    maintMarginAfter=     "",
-                    equityWithLoanAfter=  "",
+                    initMarginBefore=     NA_real_,
+                    maintMarginBefore=    NA_real_,
+                    equityWithLoanBefore= NA_real_,
+                    initMarginChange=     NA_real_,
+                    maintMarginChange=    NA_real_,
+                    equityWithLoanChange= NA_real_,
+                    initMarginAfter=      NA_real_,
+                    maintMarginAfter=     NA_real_,
+                    equityWithLoanAfter=  NA_real_,
                     commission=           NA_real_,
                     minCommission=        NA_real_,
                     maxCommission=        NA_real_,
@@ -177,7 +175,7 @@ SoftDollarTier <- list(name=        "",
 
 Order <- list(orderId=                        0L,
               clientId=                       0L,
-              permId=                         0L,
+              permId=                         "",
               action=                         "",
               totalQuantity=                  0,
               orderType=                      "",
@@ -210,13 +208,13 @@ Order <- list(orderId=                        0L,
               faMethod=                       "",
               faPercentage=                   "",
               openClose=                      "",
-              origin=                         "CUSTOMER",
+              origin=                         0L,
               shortSaleSlot=                  0L,
               designatedLocation=             "",
               exemptCode=                     -1L,
-              discretionaryAmt=               0,
+              discretionaryAmt=               NA_real_,
               optOutSmartRouting=             FALSE,
-              auctionStrategy=                "UNSET",
+              auctionStrategy=                0L,
               startingPrice=                  NA_real_,
               stockRefPrice=                  NA_real_,
               delta=                          NA_real_,
@@ -298,8 +296,8 @@ Order <- list(orderId=                        0L,
               autoCancelParent=               FALSE,
               shareholder=                    "",
               imbalanceOnly=                  FALSE,
-              routeMarketableToBbo=           FALSE,
-              parentPermId=                   NA_integer_,
+              routeMarketableToBbo=           NA,
+              parentPermId=                   "",
               usePriceMgmtAlgo=               NA,
               duration=                       NA_integer_,
               postToAts=                      NA_integer_,
@@ -315,7 +313,17 @@ Order <- list(orderId=                        0L,
               bondAccruedInterest=            "",
               includeOvernight=               FALSE,
               manualOrderIndicator=           NA_integer_,
-              submitter=                      "")
+              submitter=                      "",
+              deactivate=                     FALSE,
+              postOnly=                       FALSE,
+              allowPreOpen=                   FALSE,
+              ignoreOpenAuction=              FALSE,
+              seekPriceImprovement=           NA,
+              whatIfType=                     NA_integer_,
+              slOrderId=                      NA_integer_,
+              slOrderType=                    "",
+              ptOrderId=                      NA_integer_,
+              ptOrderType=                    "")
 
 OrderCancel <- list(manualOrderCancelTime= "",
                     extOperator=           "",
